import os
from PIL import Image
import json

# Input files
icons = {
    "light": "icon_gold_backfill_1024.png",
    "dark": "dark.png",
    "tinted": "tinted.png"
}

output_dir = "IconGold.appiconset"
os.makedirs(output_dir, exist_ok=True)

# Sizes and scales required by iOS
icon_sizes = [
    (20, [1, 2, 3]),
    (29, [1, 2, 3]),
    (40, [1, 2, 3]),
    (60, [2, 3]),
    (76, [1, 2]),
    (83.5, [2]),
    (1024, [1]),
]

# Appearance tags for Contents.json, none for light
appearance_tags = {
    "light": None,
    "dark": [{"appearance": "luminosity", "value": "dark"}],
    "tinted": [{"appearance": "luminosity", "value": "tinted"}]
}

def save_icon(image, size_pt, scale, appearance):
    px = int(size_pt * scale)
    # file name like: icon_20x20@2x_light.png
    suffix = appearance
    filename = f"icon_{int(size_pt)}x{int(size_pt)}@{scale}x_{suffix}.png"
    filepath = os.path.join(output_dir, filename)
    resized = image.resize((px, px), Image.LANCZOS)
    resized.save(filepath)
    return filename

def generate_images_for_appearance(img_path, appearance):
    image = Image.open(img_path)
    images = []
    for size, scales in icon_sizes:
        for scale in scales:
            filename = save_icon(image, size, scale, appearance)
            entry = {
                "idiom": "universal",
                "size": f"{size}x{size}",
                "scale": f"{scale}x",
                "filename": filename,
                "platform": "ios",
            }
            if appearance_tags[appearance]:
                entry["appearances"] = appearance_tags[appearance]
            images.append(entry)
    return images

# Generate all images and JSON entries
all_images = []
for appearance, filepath in icons.items():
    all_images.extend(generate_images_for_appearance(filepath, appearance))

contents = {
    "images": all_images,
    "info": {
        "version": 1,
        "author": "xcode"
    }
}

with open(os.path.join(output_dir, "Contents.json"), "w") as f:
    json.dump(contents, f, indent=4)

print("✅ IconGold asset catalog with light, dark and tinted appearances generated.")



#    Copyright 2024 Chia Network Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License");
#    you may not use this file except in compliance with the License.
#    You may obtain a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS,
#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#    See the License for the specific language governing permissions and
#    limitations under the License.

import json
import os
import pathlib
import sys
import tempfile
import venv

runner_temp = os.environ["RUNNER_TEMP"]
temporary_directory = pathlib.Path(tempfile.mkdtemp(dir=runner_temp))
github_output = pathlib.Path(os.environ["GITHUB_OUTPUT"])

python_executable: pathlib.Path
if sys.platform == "win32":
    python_executable = temporary_directory.joinpath("Scripts", "python.exe")
else:
    python_executable = temporary_directory.joinpath("bin", "python")

activate_venv_directories = json.dumps([os.fspath(temporary_directory)])

with github_output.open("a") as file:
    print(f"temp-venv-path={os.fspath(temporary_directory.as_posix())}", file=file)
    print(
        f"temp-python-executable={os.fspath(python_executable.as_posix())}",
        file=file,
    )
    print(f"activate-venv-directories={activate_venv_directories}", file=file)

venv.create(env_dir=temporary_directory, with_pip=True)



#! /usr/bin/python3
# MiniUPnP project
# Author : Thomas Bernard
# This Sample code is public domain.
# website : http://miniupnp.tuxfamily.org/

# import the python miniupnpc module
import miniupnpc
import sys

# create the object
u = miniupnpc.UPnP()
print('inital(default) values :')
print(' discoverdelay', u.discoverdelay)
print(' lanaddr', u.lanaddr)
print(' multicastif', u.multicastif)
print(' minissdpdsocket', u.minissdpdsocket)
u.discoverdelay = 200;
#u.minissdpdsocket = '../minissdpd/minissdpd.sock'
# discovery process, it usually takes several seconds (2 seconds or more)
print('Discovering... delay=%ums' % u.discoverdelay)
print(u.discover(), 'device(s) detected')
# select an igd
try:
  u.selectigd()
except Exception as e:
  print('Exception :', e)
  sys.exit(1)
# display information about the IGD and the internet connection
print('local ip address :', u.lanaddr)
print('external ip address :', u.externalipaddress())
print(u.statusinfo(), u.connectiontype())

#print u.addportmapping(64000, 'TCP',
#                       '192.168.1.166', 63000, 'port mapping test', '')
#print u.deleteportmapping(64000, 'TCP')

port = 0
proto = 'UDP'
# list the redirections :
i = 0
while True:
	p = u.getgenericportmapping(i)
	if p==None:
		break
	print(i, p)
	(port, proto, (ihost,iport), desc, c, d, e) = p
	#print port, desc
	i = i + 1

print(u.getspecificportmapping(port, proto))




#    Copyright 2024 Chia Network Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License");
#    you may not use this file except in compliance with the License.
#    You may obtain a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS,
#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#    See the License for the specific language governing permissions and
#    limitations under the License.

import os
import pathlib
import sys

reference = pathlib.Path(os.environ["REFERENCE_PATH"]).absolute()
actual = pathlib.Path(sys.executable)
expected_inside = {"true": True, "false": False}[os.environ["EXPECTED_INSIDE"]]

is_inside: bool
try:
    actual.relative_to(reference)
except ValueError:
    is_inside = False
else:
    is_inside = True

correct = expected_inside == is_inside

print(f"      reference: {reference}")
print(f"         actual: {actual}")
print(f"expected_inside: {expected_inside}")
print(f"      is_inside: {is_inside}")
print(f"        correct: {'yes' if correct else 'no'}")

if not correct:
    sys.exit(1)
